.. include:: ../../README.rst

Module documentation
====================

This reference manual contains many examples that illustrate the usage of the
slabbe package. The examples are all tested at each release and should produce
exactly the same output as in this manual.

This work is licensed under a `Creative Commons Attribution-Share Alike
3.0 License`__.

__ https://creativecommons.org/licenses/by-sa/3.0/

Dynamical systems
-----------------

.. toctree::
   :maxdepth: 1

   matrix_cocycle
   mult_cont_frac
   diophantine_approx
   lyapunov
   markov_transformation
   matrices
   polyhedron_exchange_transformation
   substitution_2d
   wang_tiles

Combinatorics
-------------

.. toctree::
   :maxdepth: 1

   joyal_bijection
   bond_percolation
   dyck_3d
   combinat
   graph
   partial_injection

Combinatorics on words
----------------------

.. toctree::
   :maxdepth: 1

   kolakoski_word
   bispecial_extension_type
   finite_word
   infinite_word
   language
   word_morphisms
   ostrowski

Digital Geometry
----------------

.. toctree::
   :maxdepth: 1

   discrete_subset
   discrete_plane
   billiard
   christoffel_graph
   double_square_tile
   polyhedron_partition

Vizualization
-------------

.. toctree::
   :maxdepth: 1

   tikz_picture

Miscellaneous
-------------

.. toctree::
   :maxdepth: 1

   analyze_sage_build
   ranking_scale
   fruit

Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
